from ufs.base import FileSystem


class S3FileSystem(FileSystem):
    @staticmethod
    def to_file(path):
        pass

    @staticmethod
    def to_directory(path):
        pass

    @staticmethod
    def to_directory_prefix(path):
        pass
